Class: FluidSynth::FluidSfontT
- Inherits:
-
FFI::Struct
- Object
- FFI::Struct
- FluidSynth::FluidSfontT
- Defined in:
- lib/ffi-fluidsynth.rb
Overview
< SoundFont loader plugin
Fields:
:data ::
(FFI::Pointer(*Void)) < User defined data
:id ::
(Integer) < SoundFont ID
:free ::
(FFI::Pointer(*)) Method to free a virtual SoundFont bank.
@param sfont Virtual SoundFont to free.
@return Should return 0 when it was able to free all resources or non-zero
if some of the samples could not be freed because they are still in use,
in which case the free will be tried again later, until success.
:get_name ::
(FFI::Pointer(*)) Method to return the name of a virtual SoundFont.
@param sfont Virtual SoundFont
@return The name of the virtual SoundFont.
:get_preset ::
(FFI::Pointer(*)) Get a virtual SoundFont preset by bank and program numbers.
@param sfont Virtual SoundFont
@param bank MIDI bank number (0-16384)
@param prenum MIDI preset number (0-127)
@return Should return an allocated virtual preset or NULL if it could not
be found.
:iteration_start ::
(FFI::Pointer(*)) Start virtual SoundFont preset iteration method.
@param sfont Virtual SoundFont
Starts/re-starts virtual preset iteration in a SoundFont.
:iteration_next ::
(FFI::Pointer(*)) Virtual SoundFont preset iteration function.
@param sfont Virtual SoundFont
@param preset Caller supplied preset to fill in with current preset information
@return 0 when no more presets are available, 1 otherwise
Should store preset information to the caller supplied \a preset structure
and advance the internal iteration state to the next preset for subsequent
calls.